@@ -1,7 +1,7 @@
 # UI-output for recoding a variable to a numeric variable
 output$ui_modify_recode_to_numeric <- renderUI({
   output$ui_to_num_var <- renderUI({
-    selectInput("sel_to_num_var",label=h5("Choose variable(s)"), choices=vv, width="50%", multiple=TRUE)
+    selectInput("sel_to_num_var",label=p("Choose variable(s)"), choices=vv, width="50%", multiple=TRUE)
   })
   output$ui_to_num_btn <- renderUI({
     req(input$sel_to_num_var)
@@ -21,8 +21,8 @@ output$ui_modify_recode_to_numeric <- renderUI({
   helptxt <- paste(helptxt, "to type 'numeric' before selecting these as numerical key variables. Here you can convert variables of type 'character' and")
   helptxt <- paste(helptxt, "type 'factor' to type 'numeric'.")
   out <- fluidRow(
-    column(12, h4("Convert character/factor variables to numeric variables"), align="center"),
-    column(12, p(helptxt), align="center"),
+    column(width = 12, offset = 0, h3("Convert character/factor variables to numeric variables"), class="wb-header"),
+    column(width = 12, offset = 0, p(helptxt), class="wb-header-hint"),
     column(12, uiOutput("ui_to_num_var"), align="center"),
     column(12, uiOutput("ui_to_num_btn"), align="center"))
   out
@@ -54,13 +54,13 @@ output$ui_modify_recode_to_factor <- renderUI({
     if (is.null(input$sel_algo)){
       return(NULL)
     }
-    return(numericInput("sl_number_breaks",label=h5("Specify number of intervals"), value=3, min=2, max=20, step=1))
+    return(numericInput("sl_number_breaks",label=p("Specify number of intervals"), value=3, min=2, max=20, step=1))
   })
   output$ui_globalRecode_manual <- renderUI({
     if (is.null(input$sel_algo)){
       return(NULL)
     }
-    sel_br <- customTextInput("txt_custom_breaks",label=h5("Specify custom breaks"), value=input$txt_custom_breaks)
+    sel_br <- customTextInput("txt_custom_breaks",label=p("Specify custom breaks"), value=input$txt_custom_breaks)
     help_br <- helpText(
       "Example input: 1,3,5,9 splits the variable into the 3 groups (1,3],(3,5] and (5,9].", br(),
       "If you supply 1 number (e.g. 3), the variable will be split in 3 equally sized groups.")
@@ -83,13 +83,13 @@ output$ui_modify_recode_to_factor <- renderUI({
     vv <- numVars()
     mult <- FALSE
     if (!is.null(input$sel_custom_split) && input$sel_custom_split=="no") {
-      selectInput("sel_num_glrec", label=h5("Choose numeric variable(s)"), choices=vv, multiple=TRUE)
+      selectInput("sel_num_glrec", label=p("Choose numeric variable(s)"), choices=vv, multiple=TRUE)
     } else {
-      radioButtons("rb_num_glrec", label=h5("Choose a numeric variable"), choices=vv, selected=input$rb_num_glrec)
+      radioButtons("rb_num_glrec", label=p("Choose a numeric variable"), choices=vv, selected=input$rb_num_glrec)
     }
   })
   output$ui_globalRecode_split <- renderUI({
-    radioButtons("sel_custom_split",label=h5("Use custom breaks?"), choices=c("no","yes"),
+    radioButtons("sel_custom_split",label=p("Use custom breaks?"), choices=c("no","yes"),
       selected=input$sel_custom_split, inline=TRUE, width="100%")
   })
   output$ui_globalRecode_cutalgo <- renderUI({
@@ -98,7 +98,7 @@ output$ui_modify_recode_to_factor <- renderUI({
     txt <- paste(txt, "- <strong>logEqui:</strong> uses breakpoints that generate intervals of equal length based on the log transformation of the data. The number of records in each interval might differ.<br />")
     txt <- paste(txt, "- <strong>equalAmount:</strong> uses breakpoints such that each group/interval has the same number of records. The intervals might be of different length.<br />")
     txt <- paste(txt, "- <strong>manual:</strong> allows the user to set the breakpoints manually. Note: make sure that all values are included in the specified intervals.")
-    selectInput("sel_algo",label=h5("Select algorithm", tipify(icon("question"), title=txt, placement="top")),
+    selectInput("sel_algo",label=p("Select algorithm", tipify(icon("info-circle"), title=txt, placement="top")),
       choices=c("equidistant","logEqui","equalAmount","manual"), selected=input$sel_algo)
   })
   output$ui_globalRecode_btn <- renderUI({
@@ -166,8 +166,9 @@ output$ui_modify_recode_to_factor <- renderUI({
   helptxt <- paste(helptxt, "be combined into one factor level, customized breaks can be specified. Several algorithms are available to customize the breaks.")
 
   out <- fluidRow(
-    column(12, h4("Convert numeric to factor", align="center"),
-    column(12, p(helptxt), align="center")))
+    column(width = 12, offset = 0, h3("Convert numeric to factor"), class="wb-header"),
+    column(width = 12, offset = 0, p(helptxt), class="wb-header-hint")
+  )
 
   if (!is.null(input$sel_custom_split) && input$sel_custom_split=="yes") {
     out <- list(out, fluidRow(
@@ -224,10 +225,10 @@ output$ui_modify_change_factor <- renderUI({
   })
   output$reclocfac_var <- renderUI({
     vv <- facVars()
-    selectInput("sel_factor", label=h5("Choose factor variable"), choices=vv, selected=input$sel_factor, width="50%")
+    selectInput("sel_factor", label=p("Choose factor variable"), choices=vv, selected=input$sel_factor, width="50%")
   })
   output$reclocfac_levs <- renderUI({
-    selectInput("cbg_factor", label=h5("Select Levels to recode/combine"),
+    selectInput("cbg_factor", label=p("Select Levels to recode/combine"),
       multiple=TRUE, selectize=TRUE, choices=curFactorVals(), width="100%")
   })
   output$reclocfac_addna <- renderUI({
@@ -240,11 +241,14 @@ output$ui_modify_change_factor <- renderUI({
   })
   output$reclocfac_txtval <- renderUI({
     req(input$cbg_factor)
-    txtval <- textInput("inp_newlevname", label=h5("New label for recoded values"),
+    txtval <- textInput("inp_newlevname", label=p("New label for recoded values"),
       value=paste0(input$cbg_factor, collapse="_"), width="100%")
   })
 
-  out <- fluidRow(column(12, h4("Group factor levels in factor variables in original data", align="center")))
+  out <- fluidRow(
+     column(12, h3("Group factor levels in factor variables in original data"), class="wb-header")
+  )
+
   if (length(facVars())==0) {
     out <- list(out, fluidRow(
       column(12, h5("There are no factor variables available that could be recoded!", align="center"))
@@ -252,8 +256,9 @@ output$ui_modify_change_factor <- renderUI({
     return(out)
   }
 
-  helptxt <- "Here you can group/combine the factor levels of categorical variables of type 'factor' before setting up the sdcMicro object."
-  out <- fluidRow(out, column(12, helptxt, align="center"))
+  helptxt <- p("Here you can group/combine the factor levels of categorical variables of type 'factor' before setting up the sdcMicro object.")
+  out <- list(out, fluidRow(
+    column(12, helptxt, class="wb-header-hint")))
   out <- list(out, fluidRow(
     column(12, uiOutput("reclocfac_var"), align="center")))
   out <- list(out, fluidRow(
@@ -271,7 +276,7 @@ output$ui_modify_change_factor <- renderUI({
 # UI-output to create a stratification variable
 output$ui_modify_create_stratvar <- renderUI({
   output$sel_genstrata <- renderUI({
-    selectInput("sel_allvars_strata",label=h5("Select variables to generate a stratification variable"), multiple=TRUE,
+    selectInput("sel_allvars_strata",label=p("Select variables to generate a stratification variable"), multiple=TRUE,
       choices=allVars(), width="100%")
   })
   output$vname_genstrata <- renderUI({
@@ -279,7 +284,7 @@ output$ui_modify_create_stratvar <- renderUI({
     if (length(input$sel_allvars_strata) < 2) {
       return(NULL)
     }
-    textInput("inp_vname_strata", label=h5("Specify variable name for stratification variable"), value=paste0(input$sel_allvars_strata, collapse="_"), width="100%")
+    textInput("inp_vname_strata", label=p("Specify variable name for stratification variable"), value=paste0(input$sel_allvars_strata, collapse="_"), width="100%")
   })
   output$btn_genstrata <- renderUI({
     req(input$sel_allvars_strata, input$inp_vname_strata)
@@ -298,8 +303,9 @@ output$ui_modify_create_stratvar <- renderUI({
   helptxt <- paste(helptxt, "By default the variable name of the stratification variable consists of the variable names separated by  '_' . You can also specify")
   helptxt <- paste(helptxt, "the variable name by typing it into the text field. The new variable is added to the loaded micro data set and will be exported.")
   out <- fluidRow(
-    column(12, h4("Create a stratification variable"), align="center"),
-    column(12, p(helptxt), align="center"))
+    column(width = 12, offset = 0, h3("Create a stratification variable"), class="wb-header"),
+    column(width = 12, offset = 0, p(helptxt), class="wb-header-hint")
+  )
 
   out <- list(out, fluidRow(
     column(6, uiOutput("sel_genstrata"), align="center"),
@@ -311,29 +317,29 @@ output$ui_modify_create_stratvar <- renderUI({
 # UI-output to set specific values to NA
 output$ui_set_to_na <- renderUI({
   output$ui_nasupptype <- renderUI({
-    radioButtons("set_to_na_type", label=h5("How to select values to recode to NA?"),
+    radioButtons("set_to_na_type", label=p("How to select values to recode to NA?"),
       choices=c("by value"="rule", "by record ID"="id"), inline=TRUE)
   })
   output$tab_inputdata_setna <- renderDataTable({
     a <- obj$inputdata
     cbind(id=1:nrow(a),a)
   },
-    options=list(scrollX=TRUE, searching=FALSE, paging=TRUE, ordering=FALSE, bInfo=FALSE))
+    options=list(scrollX=TRUE, scrollY=250, searching=FALSE, paging=TRUE, ordering=FALSE, bInfo=FALSE))
   output$ui_nasuppvar <- renderUI({
     req(input$set_to_na_type)
     multiple <- FALSE
     if (input$set_to_na_type=="id") {
       multiple <- TRUE
     }
-    res <- selectInput("sel_na_suppvar", choices=allVars(), multiple=multiple, label=h5("Select variable"), width="50%")
+    res <- selectInput("sel_na_suppvar", choices=allVars(), multiple=multiple, label=p("Select variable"), width="50%")
     return(res)
   })
   output$ui_nasuppid <- renderUI({
     req(input$sel_na_suppvar, input$set_to_na_type)
     if (input$set_to_na_type=="id") {
-      res <- numericInput("num_na_suppid", label=h5("Select record ID"), value=1, min=1, max=nrow(obj$inputdata))
+      res <- numericInput("num_na_suppid", label=p("Select record ID"), value=1, min=1, max=nrow(obj$inputdata))
     } else {
-      res <- selectInput("num_na_suppid", label=h5("Select value to recode to NA"), multiple=FALSE, choices=sort(unique(obj$inputdata[[input$sel_na_suppvar]])))
+      res <- selectInput("num_na_suppid", label=p("Select value to recode to NA"), multiple=FALSE, choices=sort(unique(obj$inputdata[[input$sel_na_suppvar]])))
     }
     return(res)
   })
@@ -361,12 +367,13 @@ output$ui_set_to_na <- renderUI({
   helptxt <- paste0("The loaded dataset may contain different missing value codes, such as",code(9),",",code(999),",",code(-9),", etc. ")
   helptxt <- paste0(helptxt, "sdcMicro can only interpret missing values that are coded",code("NA"),". Here you can set other missing value")
   helptxt <- paste0(helptxt, "codes to",code("NA"),"(by missing value code). All records with that value in the variable will be recoded to NA. Alternatively one can set individual cells to",code("NA"),"by selecting the variable and record id (by record ID).")
-  helptxt <- paste0(helptxt, " Note that it impossible to later retrieve the original missing values. R does not allow for distinct missing value codes.")  
+  helptxt <- paste0(helptxt, " Note that it impossible to later retrieve the original missing values. R does not allow for distinct missing value codes.")
 
   out <- fluidRow(
-    column(12, h4("Set missing values to NA", align="center")),
-    column(12, HTML(helptxt), align="center"),
-    column(12, uiOutput("ui_nasupptype"), align="center"))
+    column(width = 12, offset = 0, h3("Set missing values to NA"), class="wb-header"),
+    column(width = 12, offset = 0, p(HTML(helptxt)), class="wb-header-hint"),
+    column(12, uiOutput("ui_nasupptype"), align="center")
+  )
 
   out <- list(out, fluidRow(
     column(6, uiOutput("ui_nasuppvar"), align="center"),
@@ -382,7 +389,7 @@ output$ui_set_to_na <- renderUI({
 # on the class of the variable
 output$ui_view_var <- renderUI({
   output$ui_selvar1 <- renderUI({
-    selectInput("view_selvar1", choices=allVars(), label=h5("Choose a variable"), multiple=FALSE, selected=obj$inp_sel_viewvar1, width="100%")
+    selectInput("view_selvar1", choices=allVars(), label=p("Choose a variable"), multiple=FALSE, selected=obj$inp_sel_viewvar1, width="100%")
   })
   # This is required so that usual changes of the dropdown-select are also reflected in the reactive variable obj$inp_sel_viewvar1
   observeEvent(input$view_selvar1, {
@@ -390,7 +397,7 @@ output$ui_view_var <- renderUI({
   })
   output$ui_selvar2 <- renderUI({
     vv <- setdiff(allVars(), input$inp_sel_viewvar1)
-    selectInput("view_selvar2", choices=c("none", vv), label=h5("Choose a second variable (optional)"), multiple=FALSE, width="100%")
+    selectInput("view_selvar2", choices=c("none", vv), label=p("Choose a second variable (optional)"), multiple=FALSE, width="100%")
   })
 
   observeEvent(input$view_selvar1, {
@@ -425,7 +432,7 @@ output$ui_view_var <- renderUI({
       return(NULL)
     }
 
-    if (!is.null(v2) && v2!="none") {
+    if (!is.null(v2) && v2 != "none") {
       df <- data.frame(inputdata[[v1]], inputdata[[v2]])
       colnames(df) <- c(v1, v2)
       cl1 <- class(df[[1]]) %in% c("factor", "character")
@@ -435,20 +442,24 @@ output$ui_view_var <- renderUI({
       colnames(df) <- v1
       cl1 <- class(df[[1]]) %in% c("factor", "character")
     }
-    if (!is.null(v2) && v2=="none") {
+    if (!is.null(v2) && v2 == "none") {
       if (cl1) {
-        res <- list(tab=summaryfn(inputdata[[v1]]))
+        res <- list(tab = summaryfn(inputdata[[v1]]))
         colnames(res$tab) <- c(v1, "Frequency", "Percentage")
       } else {
-        res <- list(tab=as.data.frame(t(summaryfn(inputdata[[v1]]))))
+        res <- list(tab = as.data.frame(t(summaryfn(inputdata[[v1]]))))
       }
     } else {
-      # 2 factors
+      # two factors
       if (cl1 & cl2) {
-        res <- list(tab=as.data.frame.table(addmargins(table(df[[1]], df[[2]], useNA="always"))), var=c(v1, v2))
-        colnames(res$tab) <- c(res$var, "Frequency")
-        res$tab$Frequency <- as.integer(res$tab$Frequency)
-        res$tab$Percentage <- formatC(100*(res$tab$Frequency/nrow(df)), format="f", digits=2)
+        tabdf <- addmargins(table(df[[1]], df[[2]], useNA = "always"))
+        colnames(tabdf)[is.na(colnames(tabdf))] <- "NA"
+        rownames(tabdf)[is.na(rownames(tabdf))] <- "NA"
+        tabdfp <- prop.table(tabdf)
+        tabdfc <- as.data.frame(matrix(paste0(tabdf, paste0(" (", formatC(100 * tabdfp, format = "f", digits = 2),"%)")), nrow = dim(tabdf)[1], ncol = dim(tabdf)[2]))
+        colnames(tabdfc) <- colnames(tabdf)
+        rownames(tabdfc) <- rownames(tabdf)
+        res <- list(tab = as.data.frame.matrix(tabdfc), var = c(v1, v2))
       } else if (cl1 & !cl2) {
         res <- tapply(df[[2]], df[[1]], summaryfn)
         res <- do.call("rbind", res)
@@ -470,30 +481,37 @@ output$ui_view_var <- renderUI({
         tab1 <- as.data.frame(t(summaryfn(df[[1]])))
         tab2 <- as.data.frame(t(summaryfn(df[[2]])))
         vcor <- round(cor(df[[1]], df[[2]], use="pairwise.complete.obs"),3)
-        res <- list(vars=c(v1,v2),tab1=tab1, tab2=tab2, vcor=vcor)
+        res <- list(vars=c(v1,v2), tab1=tab1, tab2=tab2, vcor=vcor)
       }
     }
 
     out <- NULL
-    if (is.null(res$tab1)) {
-      out <- list(out, fluidRow(column(12, renderTable(res$tab, include.rownames=FALSE), align="center")))
-    } else {
-      out <- list(out, fluidRow(
-        column(12, h5(HTML(paste("Correlation between",code(res$vars[1]),"and",code(res$vars[2]),":",code(res$vcor))), align="center")),
-        column(12, h5(HTML(paste("Summary of Variable",code(res$vars[1]))), align="center")),
-        column(12, renderTable(res$tab1, include.rownames=FALSE), align="center"),
-        column(12, h5(HTML(paste("Summary of Variable",code(res$vars[2]))), align="center")),
-        column(12, renderTable(res$tab2, include.rownames=FALSE), align="center")))
+    if (!is.null(v2) && v2 == "none") { # univariate
+      out <- list(out, fluidRow(column(12, renderTable(res$tab, include.rownames=FALSE), class="wn-info-table")))
+    } else { # bivariate
+      if (cl1 & cl2){ # both factor
+        out <- list(out, fluidRow(
+          column(12, h5(HTML(paste("Cross-tabulation of", code(res$var[1]), "and", code(res$var[2]))))),
+          column(12, renderTable(res$tab, include.rownames=TRUE), class="wn-info-table wn-row-title")))
+      } else if ((cl1 & !cl2) | (!cl1 & cl2)){ # one factor, one numeric
+        out <- list(out, fluidRow(column(12, renderTable(res$tab, include.rownames=FALSE), class="wn-info-table")))
+      } else { # both numeric
+        out <- list(out, fluidRow(
+          column(12, h5(HTML(paste("Correlation between",code(res$vars[1]),"and",code(res$vars[2]),":",code(res$vcor))))),
+          column(12, h5(HTML(paste("Summary of variable",code(res$vars[1]))))),
+          column(12, renderTable(res$tab1, include.rownames=FALSE), class="wn-info-table"),
+          column(12, h5(HTML(paste("Summary of variable",code(res$vars[2]))))),
+          column(12, renderTable(res$tab2, include.rownames=FALSE), class="wn-info-table")))      }
     }
 
     nainfo <- data.frame(variable=c(v1, v2))
     nainfo$nr_na <- as.integer(unlist(lapply(df, function(x) { sum(is.na(x)) })))
-    nainfo$perc_na <- formatC(100*(nainfo$nr_na/nrow(df)), format="f", digits=2)
+    nainfo$perc_na <- formatC(100 * (nainfo$nr_na/nrow(df)), format = "f", digits = 2)
     out <- list(out,
-      fluidRow(column(12, "Variable",code(nainfo$variable[1]),"has",code(nainfo$nr_na[1]),"(",code(paste0(nainfo$perc_na[1],"%")),") missing values.", align="center")))
+      fluidRow(column(12, "Variable",code(nainfo$variable[1]),"has",code(nainfo$nr_na[1]),"(",code(paste0(nainfo$perc_na[1],"%")),") missing values.")))
     if (nrow(nainfo)==2 & nainfo$variable[2]!="none") {
       out <- list(out,
-        fluidRow(column(12, "Variable",code(nainfo$variable[2]),"has",code(nainfo$nr_na[2]),"(",code(paste0(nainfo$perc_na[2],"%")),") missing values.", align="center")))
+        fluidRow(column(12, "Variable",code(nainfo$variable[2]),"has",code(nainfo$nr_na[2]),"(",code(paste0(nainfo$perc_na[2],"%")),") missing values.")))
     }
     out
   })
@@ -542,10 +560,13 @@ output$ui_view_var <- renderUI({
       column(12, code(lastError()))))
   }
 
-  out <- fluidRow(column(12, h4("Explore variables in original data", align="center")))
-  rb <- radioButtons("view_rbchoice", choices=c("Plot","Summary"), selected=input$view_rbchoice, label=h5("What should be displayed?"), inline=TRUE, width="100%")
+  out <- fluidRow(
+    column(12, h3("Explore variables in original data"), class="wb-header")
+    )
+  rb <- radioButtons("view_rbchoice", choices=c("Plot","Summary"), selected=input$view_rbchoice, label=p("What should be displayed?"), inline=TRUE, width="100%")
 
   out <- list(out, fluidRow(
+    column(width = 12, offset = 0, p("Here you can view tabulations, summary statistics and graphic representations of variables and pairs of variables to explore the original data."), class="wb-header-hint"),
     column(6, uiOutput("ui_selvar1")),
     column(6, uiOutput("ui_selvar2"))))
 
@@ -559,7 +580,7 @@ output$ui_view_var <- renderUI({
 # UI-output to reset a variable to its original state
 output$ui_reset_var <- renderUI({
   output$reset_microvar_var <- renderUI({
-    selectInput("sel_reset_microvars", label=h5("Choose variable(s) to reset"),
+    selectInput("sel_reset_microvars", label=p("Choose variable(s) to reset"),
       choices=allVars(), multiple=TRUE, width="50%")
   })
 
@@ -572,8 +593,8 @@ output$ui_reset_var <- renderUI({
   txt_reset <- paste(txt_reset, "Resetting restores the variable to its original state and cancels any modifications.")
   list(
     fluidRow(
-      column(12, h4("Reset variables"), align="center"),
-      column(12, p(txt_reset), align="center"),
+      column(width = 12, offset = 0, h3("Reset variables"), class="wb-header"),
+      column(width = 12, offset = 0, p(txt_reset), class="wb-header-hint"),
       column(12, uiOutput("reset_microvar_var"), align="center"),
       column(12, uiOutput("reset_microvar_btn"), align="center")
     ))
@@ -585,13 +606,14 @@ output$ui_show_microdata <- renderUI({
     datatable(inputdata(),
               rownames = FALSE,
               selection="none",
-              options = list(scrollX=TRUE, lengthMenu=list(c(20, 50, 100, -1), c('20', '50', '100', 'All')), pageLength=20))
+              options = list(scrollX=TRUE, scrollY=250, lengthMenu=list(c(20, 50, 100, -1), c('20', '50', '100', 'All')), pageLength=20)
+              )
   })
   #, options = list(scrollX=TRUE, lengthMenu=list(c(10, 25, 100, -1), c('10', '20', '100', 'All')), pageLength=25), filter="top", rownames=FALSE
   output$tab_inputdata <- DT::renderDataTable({
     my_data_dt()
   })
-  
+
   #txt_microdata <- paste0("In this tab you can manipulate the data to prepare for setting up an object of class",code("sdcMicroObj"),"in the Anonymize tab. ")
   txt_microdata <- paste0("The loaded dataset is",code(obj$microfilename),"and consists of",code(nrow(obj$inputdata)),"observations and ",code(ncol(obj$inputdata)),"variables. ")
   if(is.null(attr(obj$inputdata, "dropped"))){
@@ -602,13 +624,13 @@ output$ui_show_microdata <- renderUI({
     #attr(obj$inputdata, "dropped")
   }
   out <- fluidRow(
-    column(12, h4("Loaded microdata"), align="center"))
+    column(width = 12, offset = 0, h3("Loaded microdata")), class="wb-header")
   if(is.null(attr(obj$inputdata, "dropped"))){
     out <- list(out, fluidRow(
-      column(12, p(HTML(txt_microdata)), align="center")))
+      column(width = 12, offset = 0, p(HTML(txt_microdata))), class="wb-header-hint"))
   }else{
     out <- list(out, fluidRow(
-      column(12, list(HTML(txt_microdata), code(lapply(attr(obj$inputdata, "dropped"), function(x) {x}))), align="center")))
+      column(width = 8, offset = 2, list(HTML(txt_microdata), code(lapply(attr(obj$inputdata, "dropped"), function(x) {x}))))))
   }
   out <- list(out, fluidRow(
     column(12, dataTableOutput("tab_inputdata"))))
@@ -617,7 +639,7 @@ output$ui_show_microdata <- renderUI({
 
 # UI-output to use only a subset of the available microdata
 output$ui_sample_microdata <- renderUI({
-  sel1 <- selectInput("sel_sdcP_sample_type", label=h5("Select a method to restrict the number of records"),
+  sel1 <- selectInput("sel_sdcP_sample_type", label=p("Select a method to restrict the number of records"),
   choices=c('n percent of the data'='n_perc',
             'the first n observations'='first_n',
             'every n-th observation'='every_n',
@@ -642,7 +664,7 @@ output$ui_sample_microdata <- renderUI({
       sl_from <- 1
       sl_to <- nrow(obj$inputdata)
     }
-    sl1 <- sliderInput("sel_sdcP_sample_n", label=h5("Set 'n' for the selected method"),
+    sl1 <- sliderInput("sel_sdcP_sample_n", label=p("Set 'n' for the selected method"),
       value=sl_val, min=sl_from, max=sl_to, step=1, width="100%")
   } else {
     sl1 <- NULL
@@ -655,8 +677,8 @@ output$ui_sample_microdata <- renderUI({
   txt_subset <- paste(txt_subset, "Note: This is solely for testing purposes to reduce the computation time and not an anonymization method. To produce an anonymized dataset this should not be used.")
 
   out <- fluidRow(
-    column(12, h4("Use only a subset of the dataset", align="center")),
-    column(12, p(txt_subset, align="center")))
+    column(12, h3("Use only a subset of the dataset"), class="wb-header"),
+    column(width = 12, offset = 0, p(txt_subset), class="wb-header-hint"))
   out <- list(out, fluidRow(
     column(6, p(sel1, align="center")),
     column(6, p(sl1, align="center"))))
@@ -677,12 +699,12 @@ output$ui_hierarchical_data_prep <- renderUI({
     return(invisible(NULL))
   })
   output$sel_hhvars_id <- renderUI({
-    selectInput("sel_hhvars_id", label=h5("Select the household id variable"),
+    selectInput("sel_hhvars_id", label=p("Select the household id variable"),
       choices=c("",allVars()), multiple=FALSE, width="75%")
   })
   output$sel_hhvars <- renderUI({
     req(input$sel_hhvars_id)
-    selectInput("sel_hhvars", label=h5("Please select all variables that refer to households and not to individuals"),
+    selectInput("sel_hhvars", label=p("Please select all variables that refer to households and not to individuals"),
       choices=setdiff(allVars(), input$sel_hhvars_id), multiple=TRUE, width="75%")
   })
   if (obj$hhdata_selected==TRUE) {
@@ -692,11 +714,11 @@ output$ui_hierarchical_data_prep <- renderUI({
       "type"=dataTypes())
     return(
       fluidRow(
-        column(12, h4("Note"), align="center"),
-        column(12, p("The current input data have already been modified to be used as household-level data. The data
+        column(width = 10, offset = 1, h4("Note"), align="center"),
+        column(width = 10, offset = 1, p("The current input data have already been modified to be used as household-level data. The data
           set contains",code(nrow(inputdata())),"observations in the following",code(ncol(inputdata())),"variables."), align="center"),
-        column(12, renderTable(df), align="center"),
-        column(12, p("If you want to work on individual-level data, you will have to delete the entire microdata file and start from scratch"), align="center")
+        column(width = 10, offset = 1, renderTable(df), align="center"),
+        column(width = 10, offset = 1, p("If you want to work on individual-level data, you will have to delete the entire microdata file and start from scratch"), align="center")
       ))
   }
 
@@ -704,17 +726,17 @@ output$ui_hierarchical_data_prep <- renderUI({
 
   if (!is.null(lastError())) {
     out <- list(out, fluidRow(
-      column(12, h4("The following Error has occured!", align="center")),
-      column(12, code(lastError()), align="center")))
+      column(width = 10, offset = 1, h4("The following Error has occured!", align="center")),
+      column(width = 10, offset = 1, code(lastError()), align="center")))
   }
 
   helptxt <- "One record per household is selected and all variables that do not pertain to the household level are removed. Do not forget to select"
   helptxt <- paste(helptxt, "a variable containing household sampling weights (if available). When setting up an sdcProblem, it is important to use correct sampling weights!")
 
   out <- list(out, fluidRow(
-    column(12, p(helptxt), align="center"),
+    column(width = 10, offset = 1, p(helptxt), align="center"),
     column(6, uiOutput("sel_hhvars_id"), align="center"), column(6, uiOutput("sel_hhvars"), align="center"),
-    column(12, uiOutput("hier_data_prep_btn"), align="center")
+    column(width = 10, offset = 1, uiOutput("hier_data_prep_btn"), align="center")
   ))
   out
 })
@@ -728,7 +750,7 @@ observeEvent(input$sel_hhvars, {
 
 output$ui_hierarchical_data_merge <- renderUI({
   output$sel_hhid_merge <- renderUI({
-    selectInput("sel_hhid_hhdata", label=h5("Select a variable containing household ids"), choices=intersect(colnames(obj$hhdata), colnames(inputdata())),
+    selectInput("sel_hhid_hhdata", label=p("Select a variable containing household ids"), choices=intersect(colnames(obj$hhdata), colnames(inputdata())),
       selected=input$sel_hhid_hhdata)
   })
   output$btn_reset_hhdata <- renderUI({
@@ -745,19 +767,19 @@ output$ui_hierarchical_data_merge <- renderUI({
       "type"=dataTypes())
     return(
       fluidRow(
-        column(12, h4("Merging of files was successful"), align="center"),
-        column(12, p("The (anonymized) household-level data were merged into the input dataset"), align="center"),
-        column(12, p("The data set contains",code(nrow(inputdata())),"observations in the following",code(ncol(inputdata())),"variables."), align="center"),
-        column(12, renderTable(df), align="center"),
-        column(12, p("In order to merge a different household level dataset, it is necessary to remove and reload the loaded microdata."), align="center")
+        column(width = 10, offset = 1, h4("Merging of files was successful"), align="center"),
+        column(width = 10, offset = 1, p("The (anonymized) household-level data were merged into the input dataset"), align="center"),
+        column(width = 10, offset = 1, p("The data set contains",code(nrow(inputdata())),"observations in the following",code(ncol(inputdata())),"variables."), align="center"),
+        column(width = 10, offset = 1, renderTable(df), align="center"),
+        column(width = 10, offset = 1, p("In order to merge a different household level dataset, it is necessary to remove and reload the loaded microdata."), align="center")
     ))
   }
 
   if (obj$hhdata_selected==TRUE) {
     return(
       fluidRow(
-        column(12, h4("Note"), align="center"),
-        column(12, p("The current input data have been modified to be used as household-level data.
+        column(width = 10, offset = 1, h4("Note"), align="center"),
+        column(width = 10, offset = 1, p("The current input data have been modified to be used as household-level data.
           It is therefore not possible, to merge additional household-level data to the current inputdata."), align="center"),
             column(12, p("To do so, you will have to delete the entire microdata file and start from scratch"), align="center")
       ))
@@ -771,24 +793,24 @@ output$ui_hierarchical_data_merge <- renderUI({
   }
   if (!is.null(obj$hhdata)) {
     out <- list(out, fluidRow(
-      column(12, p("You can reset the uploaded data by clicking the button below."), align="center"),
+      column(width = 8, offset = 2, p("You can reset the uploaded data by clicking the button below."), align="center"),
       column(12, uiOutput("btn_reset_hhdata"), align="center"),
-      column(12, h4("Continue with the merge"), align="center"),
-      column(12, p("You can now continue to merge the current household level data to the individual level microdata."), align="center"),
+      column(width = 8, offset = 2, h4("Continue with the merge"), align="center"),
+      column(width = 8, offset = 2, p("You can now continue to merge the current household level data to the individual level microdata."), align="center"),
       column(12, uiOutput("sel_hhid_merge"), align="center"),
       column(12, uiOutput("btn_merge_hhdata"), align="center")
     ))
   } else {
     out <- list(out, fluidRow(
-      column(12, p("You can now read in an already exported and anonymized household-level file to replace the household level variables in the raw dataset you read in the next step."), align="center"),
-      column(12, p("Note: the selected file is loaded immediately. Set options before selecting the file."), align="center"),
+      column(width = 8, offset = 2, p("You can now read in an already exported and anonymized household-level file to replace the household level variables in the raw dataset you read in the next step."), align="center"),
+      column(width = 8, offset = 2, p("Note: the selected file is loaded immediately. Set options before selecting the file."), align="center"),
       column(12, fileInput("file_hhfile", h5(paste0("Select File (allowed types are '.rdata')")), width="50%", accept=".rdata"), align="center")))
   }
   out
 })
 
 output$ui_hierarchical_data <- renderUI({
-  rb1 <- radioButtons("rb_hierdata_selection", label=h5("What do you want to do?"),
+  rb1 <- radioButtons("rb_hierdata_selection", label=p("What do you want to do?"),
     choices=c("Prepare file for the anonymization of household level variables"="prep_data", "Merge an anonymized household level file into the full dataset"="merge_hhdata"),
     selected=input$rb_hierdata_selection, inline=TRUE)
 
@@ -799,8 +821,9 @@ output$ui_hierarchical_data <- renderUI({
 
   out <- list(
     fluidRow(
-      column(12, h4("Deal with hierarchical Data"), align="center"),
-      column(12, p(HTML(helptxt)), align="center")),
+      column(width = 12, offset = 0, h3("Deal with hierarchical Data"), class="wb-header"),
+      column(width = 12, offset = 0, p(HTML(helptxt)), class="wb-header-hint")
+    ),
     fluidRow(column(12, rb1, align="center"))
   )
 
@@ -856,10 +879,9 @@ output$ui_modify_data_sidebar_left <- renderUI({
     if (is.null(inputdata())) {
       return(NULL)
     }
-    btn <- bsButton("btn_reset_inputdata_xx",label=("Reset inputdata"), block=TRUE, style="warning", size="extra-small")
+    btn <- myActionButton("btn_reset_inputdata_xx",label=("Reset inputdata"), "danger")
     fluidRow(
-      #column(12, h4("Reset the inputdata"), align="center"),
-      column(12, btn)
+      column(12, btn, class="wb-action-button")
     )
   })
 
@@ -883,7 +905,7 @@ output$ui_modify_data_sidebar_left <- renderUI({
 
   output$ui_sel_microdata_btns <- renderUI({
     cc <- choices_modifications()
-    out <- fluidRow(column(12, h4("What do you want to do?"), align="center"))
+    out <- fluidRow(column(12, h4("What do you want to do?")))
     for (i in 1:length(cc)) {
       id <- paste0("btn_menu_microdata_",i)
       if (obj$cur_selection_microdata==id) {
@@ -892,7 +914,9 @@ output$ui_modify_data_sidebar_left <- renderUI({
         style <- "default"
       }
       out <- list(out, fluidRow(
-        column(12, bsButton(id, label=names(cc)[i], block=TRUE, size="extra-small", style=style), tags$br())))
+        # TODO: See issue https://github.com/skounis/sdcMicro/issues/48
+        # column(12, bsButton(id, label=names(cc)[i], block=TRUE, style=style), tags$br())))
+        column(12, bsButton(id, label=names(cc)[i], block=TRUE, style=style))))
     }
     # required observers that update the color of the active button!
     eval(parse(text=genObserver_menus(pat="btn_menu_microdata_", n=1:10, updateVal="cur_selection_microdata")))
@@ -907,6 +931,6 @@ output$ui_modify_data_sidebar_left <- renderUI({
 
 output$ui_modify_data <- renderUI({
   fluidRow(
-    column(2, uiOutput("ui_modify_data_sidebar_left")),
-    column(10, uiOutput("ui_modify_data_main")))
+    column(2, uiOutput("ui_modify_data_sidebar_left"), class="wb_sidebar"),
+    column(10, uiOutput("ui_modify_data_main"), class="wb-maincolumn"))
 })
